package com.tianyi.sync.task;

import com.tianyi.sync.service.CashFlowService;
import com.tianyi.sync.service.DataSyncService;
import com.tianyi.sync.service.LiabilitiesDataSyncService;
import com.tianyi.sync.service.ProfitDataSyncService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.annotation.*;


@EnableAsync
@Configuration
@EnableScheduling
public class ScheduleTask {

    private final static Logger logger = LoggerFactory.getLogger(ScheduleTask.class);

    private final DataSyncService dataSyncService;

    private final CashFlowService cashFlowService;

    private final ProfitDataSyncService profitDataSyncService;

    private final LiabilitiesDataSyncService liabilitiesDataSyncService;

    public ScheduleTask(DataSyncService dataSyncService, CashFlowService cashFlowService, ProfitDataSyncService profitDataSyncService, LiabilitiesDataSyncService liabilitiesDataSyncService) {
        this.dataSyncService = dataSyncService;
        this.cashFlowService = cashFlowService;
        this.profitDataSyncService = profitDataSyncService;
        this.liabilitiesDataSyncService = liabilitiesDataSyncService;
    }

    /**
     * 每月3号10.30执行一次
     */
    @Async
    @Scheduled(cron = "0 30 10 3 * ? ")
    public void scheduleTask() {
        dataSyncService.sync();
        logger.info("定时任务执行成功!!!!!!");
    }

    /**
     * 每月3号10.30执行一次
     */
    @Async
    @Scheduled(cron = "0 30 10 3 * ? ")
    public void profitTask() {
        profitDataSyncService.profitSync();
        logger.info("定时任务执行成功!!!!!!");
    }

    /**
     * 每月3号10.30执行一次
     */
    @Async
    @Scheduled(cron = "0 30 10 3 * ? ")
    public void liabilitiesTask() {
        liabilitiesDataSyncService.liabilitiesSync();
        logger.info("资产负债定时任务执行成功!!!!!!");
    }

    @Async
    @Scheduled
    public void cashFlow() {
        cashFlowService.cashFlow();
        logger.info("现金流量定时任务成功！");
    }
}
